(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./encode"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var encode_1 = require("./encode");
    var latitude = 59.332438;
    var longitude = 18.118813;
    it('should return null if the input is undefined', function () {
        expect(encode_1.default(undefined)).toEqual(null);
    });
    it('should return null if the input is not an object', function () {
        expect(encode_1.default('foo')).toEqual(null);
    });
    it("should return null if the input doesn't contain longitude and latitude", function () {
        expect(encode_1.default({})).toEqual(null);
        expect(encode_1.default({ longitude: '' })).toEqual(null);
        expect(encode_1.default({ latitude: '' })).toEqual(null);
    });
    it('calculates the correct pluscode', function () {
        expect(encode_1.default({ latitude: latitude, longitude: longitude })).toEqual('9FFW84J9+XG');
    });
    it('handles coord as strings', function () {
        expect(encode_1.default({ latitude: String(latitude), longitude: String(longitude) })).toEqual('9FFW84J9+XG');
    });
    it('wraps on longitude above 180°', function () {
        expect(encode_1.default({ latitude: latitude, longitude: longitude + 360 })).toEqual('9FFW84J9+XG');
    });
    it('clamps latitudes below -90', function () {
        expect(encode_1.default({ latitude: -90.0, longitude: longitude })).toEqual('2F2W2429+2G');
        expect(encode_1.default({ latitude: -90.1, longitude: longitude })).toEqual('2F2W2429+2G');
    });
    it('has length 11 by default', function () {
        expect(encode_1.default({ latitude: latitude, longitude: longitude }).length).toEqual(11);
    });
    it('it supports sending length and adds 1 (the plus)', function () {
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 10).length).toEqual(11);
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 8).length).toEqual(9);
    });
    it('adds zero padding on lengths below 8', function () {
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 8)).toEqual('9FFW84J9+');
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 6)).toEqual('9FFW8400+');
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 4)).toEqual('9FFW0000+');
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 2)).toEqual('9F000000+');
    });
    it('it only supports lengths above 2 and below 10', function () {
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 0)).toEqual(null);
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 1)).toEqual(null);
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 11)).toEqual(null);
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 12)).toEqual(null);
    });
    it('it only even lengths', function () {
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 3)).toEqual(null);
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 5)).toEqual(null);
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 7)).toEqual(null);
        expect(encode_1.default({ latitude: latitude, longitude: longitude }, 9)).toEqual(null);
    });
});
//# sourceMappingURL=encode.spec.js.map