(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./encode", "./decode", "./utils"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var encode_1 = require("./encode");
    var decode_1 = require("./decode");
    var utils_1 = require("./utils");
    var adjust = function (axis, refAxis, resolution) {
        var refFloat = utils_1.parseNum(refAxis);
        if (axis > refFloat + resolution / 2)
            return axis - resolution;
        if (axis < refFloat - resolution / 2)
            return axis + resolution;
        return axis;
    };
    var expand = function (shortCode, ref) {
        if (!utils_1.isValidCode(shortCode))
            return null;
        if (!utils_1.isValidCoordinates(ref))
            return null;
        var prefixLength = 11 - shortCode.length;
        if (prefixLength === 0)
            return shortCode;
        var prefixedCode = encode_1.default(ref, prefixLength);
        if (!prefixedCode)
            return null;
        var code = "" + prefixedCode.slice(0, prefixLength) + shortCode;
        var coords = decode_1.default(code);
        if (!coords)
            return null;
        var latitude = coords.latitude, longitude = coords.longitude;
        var resolution = Math.pow(20, 2 - prefixLength / 2);
        return encode_1.default({
            latitude: adjust(latitude, ref.latitude, resolution),
            longitude: adjust(longitude, ref.longitude, resolution)
        });
    };
    exports.default = expand;
});
//# sourceMappingURL=expand.js.map