(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "./shorten"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var shorten_1 = require("./shorten");
    var ref = { latitude: 59.329394, longitude: 18.068712 };
    var code = '9FFW84J9+XG';
    it('returns null for non-string input', function () {
        expect(shorten_1.default(undefined, ref)).toEqual(null);
        expect(shorten_1.default(42, ref)).toEqual(null);
        expect(shorten_1.default({}, ref)).toEqual(null);
    });
    it('returns null on invalid code', function () {
        expect(shorten_1.default('invalid', ref)).toEqual(null);
    });
    it('returns null on invalid reference', function () {
        expect(shorten_1.default(code, {})).toEqual(null);
    });
    it('returns shortest code if reference is same as code', function () {
        expect(shorten_1.default(code, { latitude: 59.332438, longitude: 18.118813 })).toEqual('J9+XG');
    });
    it('returns the shortened code on a local reference', function () {
        expect(shorten_1.default(code, ref)).toEqual('84J9+XG');
    });
    it('returns the shortened code on a national reference', function () {
        expect(shorten_1.default(code, { latitude: 62.248996, longitude: 15.32562 })).toEqual('FW84J9+XG');
    });
    it('returns the full code on a global reference', function () {
        expect(shorten_1.default(code, { latitude: 59.329394, longitude: -162.068712 })).toEqual(code);
    });
});
//# sourceMappingURL=shorten.spec.js.map